==> taomu-job-server-0.0.20.6-sources.jar: cool/taomu/box/job/server/script/runtime/DataSource.java <==
package cool.taomu.box.job.server.script.runtime;

import com.google.common.base.Objects;
import cool.taomu.box.git.JGitTools;
import cool.taomu.box.git.SshProvider;
import cool.taomu.box.job.server.dao.entity.DataSourceDaoEntity;
import java.io.File;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.eclipse.jgit.transport.UsernamePasswordCredentialsProvider;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.Pure;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Accessors
@SuppressWarnings("all")
public class DataSource {
  private static final Logger LOG = LoggerFactory.getLogger(DataSource.class);
  
  private DataSourceDaoEntity dsDao;
  
  private String workspace;
  
  private JGitTools jgit;
  
  public DataSource(final DataSourceDaoEntity dsDao, final String workspace, final JGitTools jgit) {
    this.dsDao = dsDao;
    this.jgit = jgit;
    this.workspace = workspace;
  }
  
  public Boolean checkout(final String args) {
    try {
      Boolean _switchResult = null;
      int _dataSourceType = this.dsDao.getDataSourceType();
      boolean _matched = false;
      int _ordinal = DataSourceDaoEntity.DataSourceTypeEnum.GIT.ordinal();
      if (Objects.equal(_dataSourceType, _ordinal)) {
        _matched=true;
        boolean _xblockexpression = false;
        {
          File sshFile = File.createTempFile("", "pub");
          String addr = this.dsDao.getAddress();
          addr = addr.substring(0, addr.lastIndexOf("("));
          DataSource.LOG.info("git数据源:{}", addr);
          this.jgit.setRepository(this.workspace, addr);
          boolean _isReprositoryExists = this.jgit.isReprositoryExists();
          if (_isReprositoryExists) {
            this.jgit.checkout(args);
          }
          _xblockexpression = sshFile.delete();
        }
        _switchResult = Boolean.valueOf(_xblockexpression);
      }
      if (!_matched) {
        int _ordinal_1 = DataSourceDaoEntity.DataSourceTypeEnum.FTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_1)) {
          _matched=true;
          _switchResult = null;
        }
      }
      if (!_matched) {
        int _ordinal_2 = DataSourceDaoEntity.DataSourceTypeEnum.SFTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_2)) {
          _matched=true;
          _switchResult = null;
        }
      }
      return _switchResult;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public Boolean pull(final String args) {
    try {
      Boolean _switchResult = null;
      int _dataSourceType = this.dsDao.getDataSourceType();
      boolean _matched = false;
      int _ordinal = DataSourceDaoEntity.DataSourceTypeEnum.GIT.ordinal();
      if (Objects.equal(_dataSourceType, _ordinal)) {
        _matched=true;
        boolean _xblockexpression = false;
        {
          File sshFile = File.createTempFile("taomubox", "pub");
          String addr = this.dsDao.getAddress();
          int _lastIndexOf = addr.lastIndexOf("(");
          int _plus = (_lastIndexOf + 1);
          String branch = addr.substring(_plus, addr.lastIndexOf(")"));
          branch = StringUtils.<String>defaultIfBlank(args, branch);
          addr = addr.substring(0, addr.lastIndexOf("("));
          DataSource.LOG.info("git数据源:{}->{}", addr, branch);
          if ((addr.startsWith("https://") || addr.startsWith("http://"))) {
            String[] ainfo = this.dsDao.getAuthorizeInfo().split("/");
            String uname = ainfo[0];
            String upwd = ainfo[1];
            UsernamePasswordCredentialsProvider _usernamePasswordCredentialsProvider = new UsernamePasswordCredentialsProvider(uname, upwd);
            this.jgit.setCp(_usernamePasswordCredentialsProvider);
          } else {
            if ((addr.startsWith("ssh://") || addr.startsWith("git@"))) {
              SshProvider sshProvider = new SshProvider();
              FileUtils.writeStringToFile(sshFile, this.dsDao.getAuthorizeInfo().trim(), "UTF-8");
              sshProvider.setSshkeyPath(sshFile.getAbsolutePath());
              this.jgit.setSsh(sshProvider.get());
            }
          }
          this.jgit.setRepository(this.workspace, addr);
          this.jgit.setBranch(branch);
          boolean _isReprositoryExists = this.jgit.isReprositoryExists();
          if (_isReprositoryExists) {
            this.jgit.pull();
          } else {
            this.jgit.Clone();
          }
          _xblockexpression = sshFile.delete();
        }
        _switchResult = Boolean.valueOf(_xblockexpression);
      }
      if (!_matched) {
        int _ordinal_1 = DataSourceDaoEntity.DataSourceTypeEnum.FTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_1)) {
          _matched=true;
          _switchResult = null;
        }
      }
      if (!_matched) {
        int _ordinal_2 = DataSourceDaoEntity.DataSourceTypeEnum.SFTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_2)) {
          _matched=true;
          _switchResult = null;
        }
      }
      return _switchResult;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public Object push() {
    return null;
  }
  
  @Pure
  public DataSourceDaoEntity getDsDao() {
    return this.dsDao;
  }
  
  public void setDsDao(final DataSourceDaoEntity dsDao) {
    this.dsDao = dsDao;
  }
  
  @Pure
  public String getWorkspace() {
    return this.workspace;
  }
  
  public void setWorkspace(final String workspace) {
    this.workspace = workspace;
  }
  
  @Pure
  public JGitTools getJgit() {
    return this.jgit;
  }
  
  public void setJgit(final JGitTools jgit) {
    this.jgit = jgit;
  }
}

==> taomu-job-server-0.0.20.12-sources.jar: cool/taomu/box/job/server/script/runtime/DataSource.java <==
package cool.taomu.box.job.server.script.runtime;

import com.google.common.base.Objects;
import cool.taomu.box.git.JGitTools;
import cool.taomu.box.git.SshProvider;
import cool.taomu.box.job.server.dao.entity.DataSourceDaoEntity;
import java.io.File;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.eclipse.jgit.transport.UsernamePasswordCredentialsProvider;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.Pure;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Accessors
@SuppressWarnings("all")
public class DataSource {
  private static final Logger LOG = LoggerFactory.getLogger(DataSource.class);
  
  private DataSourceDaoEntity dsDao;
  
  private String workspace;
  
  private JGitTools jgit;
  
  public DataSource(final DataSourceDaoEntity dsDao, final String workspace, final JGitTools jgit) {
    this.dsDao = dsDao;
    this.jgit = jgit;
    this.workspace = workspace;
  }
  
  public Boolean checkout(final String args) {
    try {
      Boolean _switchResult = null;
      int _dataSourceType = this.dsDao.getDataSourceType();
      boolean _matched = false;
      int _ordinal = DataSourceDaoEntity.DataSourceTypeEnum.GIT.ordinal();
      if (Objects.equal(_dataSourceType, _ordinal)) {
        _matched=true;
        boolean _xblockexpression = false;
        {
          File sshFile = File.createTempFile("", "pub");
          String addr = this.dsDao.getAddress();
          addr = addr.substring(0, addr.lastIndexOf("("));
          DataSource.LOG.info("git数据源:{}", addr);
          this.jgit.setRepository(this.workspace, addr);
          boolean _isReprositoryExists = this.jgit.isReprositoryExists();
          if (_isReprositoryExists) {
            this.jgit.checkout(args);
          }
          _xblockexpression = sshFile.delete();
        }
        _switchResult = Boolean.valueOf(_xblockexpression);
      }
      if (!_matched) {
        int _ordinal_1 = DataSourceDaoEntity.DataSourceTypeEnum.FTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_1)) {
          _matched=true;
          _switchResult = null;
        }
      }
      if (!_matched) {
        int _ordinal_2 = DataSourceDaoEntity.DataSourceTypeEnum.SFTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_2)) {
          _matched=true;
          _switchResult = null;
        }
      }
      return _switchResult;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public Boolean pull(final String args) {
    try {
      Boolean _switchResult = null;
      int _dataSourceType = this.dsDao.getDataSourceType();
      boolean _matched = false;
      int _ordinal = DataSourceDaoEntity.DataSourceTypeEnum.GIT.ordinal();
      if (Objects.equal(_dataSourceType, _ordinal)) {
        _matched=true;
        boolean _xblockexpression = false;
        {
          File sshFile = File.createTempFile("taomubox", "pub");
          String addr = this.dsDao.getAddress();
          int _lastIndexOf = addr.lastIndexOf("(");
          int _plus = (_lastIndexOf + 1);
          String branch = addr.substring(_plus, addr.lastIndexOf(")"));
          branch = StringUtils.<String>defaultIfBlank(args, branch);
          addr = addr.substring(0, addr.lastIndexOf("("));
          DataSource.LOG.info("git数据源:{}->{}", addr, branch);
          if ((addr.startsWith("https://") || addr.startsWith("http://"))) {
            DataSource.LOG.info("远程仓库地址:{}", addr);
            String[] ainfo = this.dsDao.getAuthorizeInfo().split("/");
            String uname = ainfo[0];
            String upwd = ainfo[1];
            UsernamePasswordCredentialsProvider _usernamePasswordCredentialsProvider = new UsernamePasswordCredentialsProvider(uname, upwd);
            this.jgit.setCp(_usernamePasswordCredentialsProvider);
          } else {
            if ((addr.startsWith("ssh://") || addr.startsWith("git@"))) {
              DataSource.LOG.info("远程仓库地址:{}", addr);
              SshProvider sshProvider = new SshProvider();
              FileUtils.writeStringToFile(sshFile, this.dsDao.getAuthorizeInfo().trim(), "UTF-8");
              sshProvider.setSshkeyPath(sshFile.getAbsolutePath());
              this.jgit.setSsh(sshProvider.get());
            }
          }
          this.jgit.setRepository(this.workspace.trim(), addr);
          this.jgit.setBranch(branch);
          boolean _isReprositoryExists = this.jgit.isReprositoryExists();
          if (_isReprositoryExists) {
            this.jgit.pull();
          } else {
            this.jgit.Clone();
          }
          _xblockexpression = sshFile.delete();
        }
        _switchResult = Boolean.valueOf(_xblockexpression);
      }
      if (!_matched) {
        int _ordinal_1 = DataSourceDaoEntity.DataSourceTypeEnum.FTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_1)) {
          _matched=true;
          _switchResult = null;
        }
      }
      if (!_matched) {
        int _ordinal_2 = DataSourceDaoEntity.DataSourceTypeEnum.SFTP.ordinal();
        if (Objects.equal(_dataSourceType, _ordinal_2)) {
          _matched=true;
          _switchResult = null;
        }
      }
      return _switchResult;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public Object push() {
    return null;
  }
  
  @Pure
  public DataSourceDaoEntity getDsDao() {
    return this.dsDao;
  }
  
  public void setDsDao(final DataSourceDaoEntity dsDao) {
    this.dsDao = dsDao;
  }
  
  @Pure
  public String getWorkspace() {
    return this.workspace;
  }
  
  public void setWorkspace(final String workspace) {
    this.workspace = workspace;
  }
  
  @Pure
  public JGitTools getJgit() {
    return this.jgit;
  }
  
  public void setJgit(final JGitTools jgit) {
    this.jgit = jgit;
  }
}
